@@ -1,62 +1,41 @@
 from __future__ import unicode_literals
 
-from optparse import make_option
-try:
-    from collections import OrderedDict
-except ImportError:  # For Python 2.6
-    from django.utils.datastructures import SortedDict as OrderedDict
-
-try:
-    from django.apps import apps
-    try:
-        get_app = apps.get_app
-    except AttributeError:  # For Django >= 1.9
-        get_app = lambda app_label: apps.get_app_config(app_label).models_module
-    try:
-        get_apps = apps.get_apps
-    except AttributeError:  # For Django >= 1.9
-        get_apps = lambda: [app_config.models_module for app_config in apps.get_app_configs() if app_config.models_module is not None]
-    get_model = apps.get_model
-    get_models = apps.get_models
-except ImportError:  # For Django < 1.7
-    from django.db.models import get_app, get_apps, get_model, get_models
-
-try:
-    from importlib import import_module
-except ImportError:  # For Django < 1.8
-    from django.utils.importlib import import_module
+from collections import OrderedDict
+from importlib import import_module
 
+from django.apps import apps
+from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.management.base import BaseCommand
 from django.core.management.base import CommandError
 from django.contrib.contenttypes.models import ContentType
 from django.db import reset_queries
+from django.utils import translation
 from django.utils.encoding import force_text
 
 from reversion.revisions import default_revision_manager
 from reversion.models import Version, has_int_pk
-from django.utils import translation
-from django.conf import settings
+
+get_app = lambda app_label: apps.get_app_config(app_label).models_module
 
 
 class Command(BaseCommand):
-    option_list = BaseCommand.option_list + (
-        make_option("--comment",
+    help = "Creates initial revisions for a given app [and model]."
+
+    def add_arguments(self, parser):
+        parser.add_argument('args', metavar='app_label', nargs='*',
+            help="Optional apps or app.Model list.")
+        parser.add_argument("--comment",
             action="store",
-            dest="comment",
             default="Initial version.",
-            help='Specify the comment to add to the revisions. Defaults to "Initial version.".'),
-        make_option("--batch-size",
+            help='Specify the comment to add to the revisions. Defaults to "Initial version.".')
+        parser.add_argument("--batch-size",
             action="store",
-            dest="batch_size",
             type=int,
             default=500,
-            help="For large sets of data, revisions will be populated in batches. Defaults to 500"),
-        make_option('--database', action='store', dest='database',
-            help='Nominates a database to create revisions in.'),
-        )
-    args = '[appname, appname.ModelName, ...] [--comment="Initial version."]'
-    help = "Creates initial revisions for a given app [and model]."
+            help="For large sets of data, revisions will be populated in batches. Defaults to 500.")
+        parser.add_argument("--database",
+            help='Nominates a database to create revisions in.')
 
     def handle(self, *app_labels, **options):
 
@@ -71,10 +50,12 @@ class Command(BaseCommand):
         app_list = OrderedDict()
         # if no apps given, use all installed.
         if len(app_labels) == 0:
-            for app in get_apps():
+            all_apps = [config.models_module for config in apps.get_app_configs()
+                        if config.models_module is not None]
+            for app in all_apps:
                 if not app in app_list:
                     app_list[app] = []
-                for model_class in get_models(app):
+                for model_class in apps.get_models(app):
                     if not model_class in app_list[app]:
                         app_list[app].append(model_class)
         else:
@@ -86,7 +67,7 @@ class Command(BaseCommand):
                     except ImproperlyConfigured:
                         raise CommandError("Unknown application: %s" % app_label)
 
-                    model_class = get_model(app_label, model_label)
+                    model_class = apps.get_model(app_label, model_label)
                     if model_class is None:
                         raise CommandError("Unknown model: %s.%s" % (app_label, model_label))
                     if app in app_list:
@@ -101,7 +82,7 @@ class Command(BaseCommand):
                         app = get_app(app_label)
                         if not app in app_list:
                             app_list[app] = []
-                        for model_class in get_models(app):
+                        for model_class in apps.get_models(app):
                             if not model_class in app_list[app]:
                                 app_list[app].append(model_class)
                     except ImproperlyConfigured:
