@@ -9,12 +9,7 @@ from weakref import WeakValueDictionary
 import copy
 from collections import defaultdict
 
-try:
-    from django.apps import apps
-    get_model = apps.get_model
-except ImportError:  # For Django < 1.7  pragma: no cover
-    from django.db.models import get_model
-
+from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
 from django.core import serializers
 from django.core.exceptions import ObjectDoesNotExist
@@ -25,7 +20,6 @@ from django.db.models.query import QuerySet
 from django.db.models.signals import post_save
 from django.utils.encoding import force_text
 
-from reversion.models import Revision, Version, has_int_pk
 from reversion.signals import pre_revision_commit, post_revision_commit
 from reversion.errors import RevisionManagementError, RegistrationError
 
@@ -103,6 +97,7 @@ class VersionAdapter(object):
 
     def get_version_data(self, obj, db=None):
         """Creates the version data to be saved to the version model."""
+        from reversion.models import has_int_pk
         object_id = force_text(obj.pk)
         content_type = ContentType.objects.db_manager(db).get_for_model(obj)
         if has_int_pk(obj.__class__):
@@ -378,7 +373,7 @@ class RevisionManager(object):
     def get_registered_models(self):
         """Returns an iterable of all registered models."""
         return [
-            get_model(*key)
+            apps.get_model(*key)
             for key
             in self._registered_models.keys()
         ]
@@ -452,12 +447,14 @@ class RevisionManager(object):
 
     def _get_versions(self, db=None):
         """Returns all versions that apply to this manager."""
+        from reversion.models import Version
         return Version.objects.using(db).filter(
             revision__manager_slug = self._manager_slug,
         ).select_related("revision")
 
     def save_revision(self, objects, ignore_duplicates=False, user=None, comment="", meta=(), db=None):
         """Saves a new revision."""
+        from reversion.models import Revision, Version, has_int_pk
         # Adapt the objects to a dict.
         if isinstance(objects, (list, tuple)):
             objects = dict(
@@ -468,7 +465,7 @@ class RevisionManager(object):
         if objects:
             # Follow relationships.
             for obj in self._follow_relationships(objects.keys()):
-                if not obj in objects:
+                if obj not in objects:
                     adapter = self.get_adapter(obj.__class__)
                     objects[obj] = adapter.get_version_data(obj)
             # Create all the versions without saving them
@@ -529,6 +526,7 @@ class RevisionManager(object):
 
         The results are returned with the most recent versions first.
         """
+        from reversion.models import has_int_pk
         content_type = ContentType.objects.db_manager(db).get_for_model(model)
         versions = self._get_versions(db).filter(
             content_type = content_type,
@@ -565,6 +563,7 @@ class RevisionManager(object):
 
     def get_for_date(self, object, date, db=None):
         """Returns the latest version of an object for the given date."""
+        from reversion.models import Version
         versions = self.get_for_object(object, db)
         versions = versions.filter(revision__date_created__lte=date)
         try:
@@ -580,6 +579,7 @@ class RevisionManager(object):
 
         The results are returned with the most recent versions first.
         """
+        from reversion.models import has_int_pk
         model_db = model_db or db
         content_type = ContentType.objects.db_manager(db).get_for_model(model_class)
         live_pk_queryset = model_class._default_manager.db_manager(model_db).all().values_list("pk", flat=True)
