@@ -9,7 +9,9 @@ from reversion.admin import VersionAdmin
 from test_reversion.models import (
     ChildTestAdminModel,
     InlineTestChildModel,
+    InlineTestChildModelProxy,
     InlineTestParentModel,
+    InlineTestParentModelProxy,
     InlineTestUnrelatedChildModel,
     InlineTestUnrelatedParentModel,
     InlineTestChildGenericModel,
@@ -24,6 +26,17 @@ class ChildTestAdminModelAdmin(VersionAdmin):
 admin.site.register(ChildTestAdminModel, ChildTestAdminModelAdmin)
 
 
+class InlineTestChildModelProxyInline(admin.TabularInline):
+
+    model = InlineTestChildModelProxy
+
+    extra = 0
+
+    verbose_name = "Proxy child"
+
+    verbose_name_plural = "Proxy children"
+
+
 class InlineTestChildModelInline(admin.TabularInline):
 
     model = InlineTestChildModel
@@ -48,12 +61,20 @@ class InlineTestChildGenericModelInline(GenericTabularInline):
 
 class InlineTestParentModelAdmin(VersionAdmin):
 
-    inlines = (InlineTestChildModelInline, InlineTestChildGenericModelInline)
+    inlines = (InlineTestChildModelInline, InlineTestChildGenericModelInline,)
 
 
 admin.site.register(InlineTestParentModel, InlineTestParentModelAdmin)
 
 
+class InlineTestParentModelProxyAdmin(VersionAdmin):
+
+    inlines = (InlineTestChildModelProxyInline,)
+
+
+admin.site.register(InlineTestParentModelProxy, InlineTestParentModelProxyAdmin)
+
+
 class InlineTestUnrelatedChildModelInline(admin.TabularInline):
 
     model = InlineTestUnrelatedChildModel
