@@ -1,7 +1,5 @@
 """
 Tests for the django-reversion API.
-
-These tests require Python 2.5 to run.
 """
 
 from __future__ import unicode_literals
@@ -15,12 +13,7 @@ from django.core.management import call_command
 from django.core.exceptions import ImproperlyConfigured
 from django.conf import settings
 from django.contrib import admin
-try:
-    from django.contrib.auth import get_user_model
-except ImportError: # django < 1.5  pragma: no cover
-    from django.contrib.auth.models import User
-else:
-    User = get_user_model()
+from django.contrib.auth import get_user_model
 from django.db.models.signals import pre_delete
 from django.utils import timezone
 from django.core.urlresolvers import reverse, resolve
@@ -63,11 +56,14 @@ from test_reversion.models import (
     ParentTestAdminModel,
     ChildTestAdminModel,
     InlineTestParentModel,
+    InlineTestParentModelProxy,
     InlineTestChildModel,
-    InlineTestChildGenericModel
+    InlineTestChildGenericModel,
+    InlineTestChildModelProxy,
 )
 from test_reversion import admin  # Force early registration of all admin models.
 
+User = get_user_model()
 
 ZERO = datetime.timedelta(0)
 
@@ -172,20 +168,6 @@ class ReversionTestBase(TestCase):
         unregister(ReversionTestModel1)
         unregister(ReversionTestModel2)
         unregister(ReversionTestModel3)
-        # Delete the test models.
-        ReversionTestModel1.objects.all().delete()
-        ReversionTestModel2.objects.all().delete()
-        ReversionTestModel3.objects.all().delete()
-        User.objects.all().delete()
-        del self.test11
-        del self.test12
-        del self.test21
-        del self.test22
-        del self.test31
-        del self.test32
-        del self.user
-        # Delete the revisions index.
-        Revision.objects.all().delete()
         # Unregister all remaining models.
         for registered_model in get_registered_models():
             unregister(registered_model)
@@ -470,10 +452,6 @@ class MultiTableInheritanceApiTest(RevisionTestBase):
     def testCanRetreiveFullFieldDict(self):
         self.assertEqual(get_for_object(self.testchild1)[0].field_dict["name"], "modelchild1 instance1 version 1")
 
-    def tearDown(self):
-        super(MultiTableInheritanceApiTest, self).tearDown()
-        del self.testchild1
-
 
 class ReversionTestModel1ChildProxy(ReversionTestModel1Child):
     class Meta:
@@ -620,8 +598,6 @@ class FollowModelsTest(ReversionTestBase):
 
     def tearDown(self):
         unregister(TestFollowModel)
-        TestFollowModel.objects.all().delete()
-        del self.follow1
         super(FollowModelsTest, self).tearDown()
 
 
@@ -682,6 +658,15 @@ class CreateInitialRevisionsTest(ReversionTestBase):
         self.assertEqual(Revision.objects.all()[0].comment, "Foo bar")
 
 
+class DeleteRevisionsTest(ReversionTestBase):
+
+    def testDeleteRevisions(self):
+        call_command("createinitialrevisions")
+        self.assertGreater(Version.objects.count(), 4)
+        call_command("deleterevisions", "test_reversion", confirmation=False, verbosity=0)
+        self.assertEqual(Version.objects.count(), 0)
+
+
 # Tests for reversion functionality that's tied to requests.
 
 class RevisionMiddlewareTest(ReversionTestBase):
@@ -707,10 +692,6 @@ class RevisionMiddlewareTest(ReversionTestBase):
 class VersionAdminTest(TestCase):
 
     def setUp(self):
-        self.old_TEMPLATE_DIRS = settings.TEMPLATE_DIRS
-        settings.TEMPLATE_DIRS = (
-            os.path.join(os.path.dirname(admin.__file__), "templates"),
-        )
         self.user = User(
             username = "foo",
             is_staff = True,
@@ -724,6 +705,9 @@ class VersionAdminTest(TestCase):
             password = "bar",
         )
 
+    def tearDown(self):
+        self.client.logout()
+
     def testAutoRegisterWorks(self):
         self.assertTrue(is_registered(ChildTestAdminModel))
         self.assertTrue(is_registered(ParentTestAdminModel))
@@ -829,10 +813,10 @@ class VersionAdminTest(TestCase):
         parent = InlineTestParentModel.objects.get(id=parent_pk)
         # Update  instance via the admin to add a child
         response = self.client.post(reverse("admin:test_reversion_inlinetestparentmodel_change", args=(parent_pk,)), {
-            "name": "parent version1",
+            "name": "parent version2",
             "children-TOTAL_FORMS": "1",
             "children-INITIAL_FORMS": "0",
-            "children-0-name": "child version 1",
+            "children-0-name": "non-generic child version 1",
             "test_reversion-inlinetestchildgenericmodel-content_type-object_id-TOTAL_FORMS": "1",
             "test_reversion-inlinetestchildgenericmodel-content_type-object_id-INITIAL_FORMS": "0",
             "test_reversion-inlinetestchildgenericmodel-content_type-object_id-0-name": "generic child version 1",
@@ -846,28 +830,68 @@ class VersionAdminTest(TestCase):
         # get list of versions
         version_list = get_for_object(parent)
         self.assertEqual(len(version_list), 2)
+        # All done!
+        return parent_pk
 
     def testInlineAdmin(self):
         self.assertTrue(is_registered(InlineTestParentModel))
         # make sure model is following the child FK
         self.assertTrue('children' in get_adapter(InlineTestParentModel).follow)
-        self.createInlineObjects()
-        # unregister model
-        unregister(InlineTestParentModel)
-        self.assertFalse(is_registered(InlineTestParentModel))
-        # re-register without following
-        register(InlineTestParentModel)
-        self.assertTrue(is_registered(InlineTestParentModel))
-        # make sure model is NOT following the child FK
-        self.assertFalse('children' in get_adapter(InlineTestParentModel).follow)
-        self.createInlineObjects()
+        parent_pk = self.createInlineObjects()
+        # Check that the current version includes the inlines.
+        versions = list(get_for_object_reference(InlineTestParentModel, parent_pk))
+        response = self.client.get(reverse("admin:test_reversion_inlinetestparentmodel_revision", args=(parent_pk, versions[0].pk)))
+        self.assertContains(response, "parent version2")  # Check parent model.
+        self.assertContains(response, "non-generic child version 1")  # Check inline child model.
+        self.assertContains(response, "generic child version 1")  # Check inline generic child model.
+        # Check that the first version does not include the inlines.
+        response = self.client.get(reverse("admin:test_reversion_inlinetestparentmodel_revision", args=(parent_pk, versions[1].pk)))
+        self.assertContains(response, "parent version1")  # Check parent model.
+        self.assertNotContains(response, "non-generic child version 1")  # Check inline child model.
+        self.assertNotContains(response, "generic child version 1")  # Check inline generic child model.
 
-    def tearDown(self):
-        self.client.logout()
-        self.user.delete()
-        del self.user
-        ChildTestAdminModel.objects.all().delete()
-        settings.TEMPLATE_DIRS = self.old_TEMPLATE_DIRS
+    def createInlineProxyObjects(self):
+        # Create an instance via the admin without a child.
+        response = self.client.post(reverse("admin:test_reversion_inlinetestparentmodelproxy_add"), {
+            "name": "parent version1",
+            "children-TOTAL_FORMS": "0",
+            "children-INITIAL_FORMS": "0",
+            "_continue": 1,
+            })
+        self.assertEqual(response.status_code, 302)
+        parent_pk = resolve(response["Location"].replace("http://testserver", "")).args[0]
+        parent = InlineTestParentModelProxy.objects.get(id=parent_pk)
+        # Update  instance via the admin to add a child
+        response = self.client.post(reverse("admin:test_reversion_inlinetestparentmodelproxy_change", args=(parent_pk,)), {
+            "name": "parent version2",
+            "children-TOTAL_FORMS": "1",
+            "children-INITIAL_FORMS": "0",
+            "children-0-name": "non-generic child version 1",
+            "_continue": 1,
+            })
+        self.assertEqual(response.status_code, 302)
+        children = InlineTestChildModelProxy.objects.filter(parent=parent_pk)
+        self.assertEqual(children.count(), 1)
+        # get list of versions
+        version_list = get_for_object(parent)
+        self.assertEqual(len(version_list), 2)
+        # All done!
+        return parent_pk
+
+    def testInlineProxyAdmin(self):
+        self.assertTrue(is_registered(InlineTestParentModelProxy))
+        # make sure model is following the child FK
+        self.assertTrue('children' in get_adapter(InlineTestParentModelProxy).follow)
+        parent_pk = self.createInlineProxyObjects()
+        # Check that the current version includes the inlines.
+        versions = list(get_for_object_reference(InlineTestParentModelProxy, parent_pk))
+        response = self.client.get(reverse("admin:test_reversion_inlinetestparentmodelproxy_revision", args=(parent_pk, versions[0].pk)))
+        self.assertContains(response, "parent version2")  # Check parent model.
+        self.assertContains(response, "non-generic child version 1")  # Check inline child model.
+        # Check that the first version does not include the inlines.
+        response = self.client.get(reverse("admin:test_reversion_inlinetestparentmodelproxy_revision", args=(parent_pk, versions[1].pk)))
+        self.assertContains(response, "parent version1")  # Check parent model.
+        self.assertNotContains(response, "non-generic child version 1")  # Check inline child model.
 
 
 # Tests for optional patch generation methods.
@@ -903,11 +927,6 @@ class PatchTest(RevisionTestBase):
             '<span>model1 instance1 version</span><del style="background:#ffe6e6;">1</del><ins style="background:#e6ffe6;">2</ins>',
         )
 
-    def tearDown(self):
-        super(PatchTest, self).tearDown()
-        del self.version1
-        del self.version2
-
 
 # test preserve deleted User Revisions
 class DeleteUserTest(RevisionTestBase):
